function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

/*
 * Copyright (c) 2022 Anton Bagdatyev (Tonix)
 *
 * Permission is hereby granted, free of charge, to any person
 * obtaining a copy of this software and associated documentation
 * files (the "Software"), to deal in the Software without
 * restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following
 * conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
 * HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */
import { useLayoutEffect, useCallback } from "react";
import useWindowRef from "./useWindowRef";
import usePOJOState from "./usePOJOState";
import useCumulativeShallowDiff from "./useCumulativeShallowDiff";
import { pick } from "js-utl";
/**
 * @type {Object}
 */

var initialDimensions = {
  width: void 0,
  height: void 0
};
/**
 * @type {string[]}
 */

var defaultDimensionProps = ["width", "height"];
/**
 * Hook to get the dimensions of a DOM element.
 *
 * @param {string|Element|Object} element A selector of a DOM element, a DOM element or a ref object.
 * @param {string[]} dimensionProps Array of dimension props to track.
 *                                  Defaults to ['width', 'height'], i.e. track both width and height.
 * @return {Array|Object} The return value of this hook can be destructured as an array as well as an object.
 *
 *                        When destructuring it as an array, the array will have the dimensions object
 *                        having "width" and "height" properties as its first element and a "forceSetDimensions"
 *                        function as its second element which, if called, will force the recalculation
 *                        of the width and height of the element.
 *
 *                        When destructuring an object, the object will have the "width" and "height" of the DOM element,
 *                        as well as the "forceSetDimensions" function as properties.
 *
 *                        Initially, on first render, both "width" and "height" will be "undefined".
 */

export default function useElementSize(element) {
  var dimensionProps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : defaultDimensionProps;
  dimensionProps = useCumulativeShallowDiff(dimensionProps);

  var _usePOJOState = usePOJOState(function () {
    return pick.apply(void 0, _toConsumableArray(dimensionProps))(initialDimensions);
  }),
      _usePOJOState2 = _slicedToArray(_usePOJOState, 2),
      dimensions = _usePOJOState2[0],
      setDimensions = _usePOJOState2[1];

  var windowRef = useWindowRef();
  var forceSetDimensions = useCallback(function () {
    var finalElement = typeof element === "string" ? document.querySelector(element) : Object.prototype.hasOwnProperty.call(element, "current") ? element.current : element;

    if (finalElement) {
      var boundingClientRect = finalElement.getBoundingClientRect();

      var _dimensions = pick.apply(void 0, _toConsumableArray(dimensionProps))(boundingClientRect);

      setDimensions(_dimensions);
    } else {
      setDimensions(initialDimensions);
    }
  }, [element, setDimensions, dimensionProps]);
  useLayoutEffect(function () {
    var window = windowRef.current && windowRef.current.addEventListener("resize", forceSetDimensions);
    forceSetDimensions();
    return function () {
      window && window.removeEventListener("resize", forceSetDimensions);
    };
  }, [windowRef, forceSetDimensions]);
  var ret = [dimensions, forceSetDimensions];

  for (var prop in dimensions) {
    ret[prop] = dimensions[prop];
  }

  ret.forceSetDimensions = forceSetDimensions;
  return ret;
}
//# sourceMappingURL=useElementSize.js.map